@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -12,19 +12,17 @@ use std::str;
 use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 use serde_with::{skip_serializing_none, DeserializeFromStr, SerializeDisplay};
+use statehub_location::{AwsRegion, AzureRegion, Location};
 use uuid::Uuid;
 
-use crate::location::{CloudLocation, InvalidLocation, Location};
-
-pub use self::aws::{AwsRegion, PrivateLinkServiceAws};
-pub use self::azure::{AzureRegion, PrivateLinkServiceAzure};
+pub use self::aws::PrivateLinkServiceAws;
+pub use self::azure::PrivateLinkServiceAzure;
 pub use self::cluster::{
     Cluster, ClusterLocationAws, ClusterLocationAzure, ClusterLocations, ClusterName, ClusterToken,
     CreateClusterDto, Provider,
 };
 pub use self::error::{Error, Permission, StatehubError};
 pub use self::events::{Report, Reporter};
-pub use self::gcp::GcpRegion;
 pub use self::helm::Helm;
 pub use self::login::Login;
 pub use self::state::{
@@ -42,7 +40,6 @@ mod azure;
 mod cluster;
 mod error;
 mod events;
-mod gcp;
 mod helm;
 mod login;
 mod state;
